Learn R Programming

mpspline2 (version 0.1.9)

mpspline_datchk: pre-spline data checks

Description

Runs a few data quality checks and makes some repairs where possible.

Usage

mpspline_datchk(s = NULL, var_name = NULL)

Value

If data passes checks it is returned unchanged. Sites with no data to spline and sites with overlapping input depth ranges return NA.

Arguments

s

data frame, input data for a single soil profile.

var_name

character or integer vector denoting the column(s) in site in which target data is stored. If not supplied, the fourth column of the input object is assumed to contain the target data.