Learn R Programming

mpspline2 (version 0.1.9)

mpspline_est1: Estimate spline parameters

Description

Estimate key parameters for building a mass-preserving spline across a single soil profile

Usage

mpspline_est1(s = NULL, var_name = NULL, lam = NULL)

Value

A list of parameters used for spline fitting.

Arguments

s

data.frame containing a single profile's worth of soil info

var_name

character or integer vector denoting the column(s) in site in which target data is stored. If not supplied, the fourth column of the input object is assumed to contain the target data.

lam

number; smoothing parameter for spline. Defaults to 0.1.