Learn R Programming

mpspline2 (version 0.1.9)

mpspline_rmse1: calculate RMSE

Description

Calculates Root Mean Squared Error (RMSE) for estimates on a single site

Usage

mpspline_rmse1(s = NULL, p = NULL, var_name = NULL)

Value

length-2 named numeric - RMSE and RMSE scaled against input data's interquartile range.

Arguments

s

data.frame; data for one site

p

list; estimated spline parameters for one site from mpspline_est1

var_name

character or integer vector denoting the column(s) in site in which target data is stored. If not supplied, the fourth column of the input object is assumed to contain the target data.