Fit spline parameters to data for a single site.
mpspline_fit1(
s = NULL,
p = NULL,
var_name = NULL,
d = NULL,
vhigh = NULL,
vlow = NULL
)list of two vectors: fitted values at 1cm intervals and the average of same over the requested depth ranges.
data.frame; data for one site
list; estimated spline parameters for one site from
mpspline_est1
character or integer vector denoting the column(s) in
obj in which target data is stored. If not supplied, the fourth
column of the input object is assumed to contain the target data.
sequential integer vector; denotes the output depth ranges in cm.
Defaults to c(0, 5, 15, 30, 60, 100, 200) after the GlobalSoilMap
specification, giving output predictions over intervals 0-5cm, 5-15cm,
etc.
numeric; constrains the maximum predicted value to a realistic number. Defaults to 1000.
numeric; constrains the minimum predicted value to a realistic number. Defaults to 0.